diff decoders/aiff.c @ 47:ea58bc3b15d7

Added init() and quit() methods.
author Ryan C. Gordon <icculus@icculus.org>
date Sat, 22 Sep 2001 14:41:38 +0000
parents 0d5ff5679523
children b13fafb976be
line wrap: on
line diff
--- a/decoders/aiff.c	Sat Sep 22 14:41:10 2001 +0000
+++ b/decoders/aiff.c	Sat Sep 22 14:41:38 2001 +0000
@@ -57,7 +57,8 @@
 #error SOUND_SUPPORTS_AIFF must be defined.
 #endif
 
-
+static int AIFF_init(void);
+static void AIFF_quit(void);
 static int AIFF_open(Sound_Sample *sample, const char *ext);
 static void AIFF_close(Sound_Sample *sample);
 static Uint32 AIFF_read(Sound_Sample *sample);
@@ -71,9 +72,11 @@
         "http://www.icculus.org/SDL_sound/"
     },
 
-    AIFF_open,      /* open() method       */
-    AIFF_close,     /* close() method       */
-    AIFF_read       /* read() method       */
+    AIFF_init,      /*  init() method */
+    AIFF_quit,      /*  quit() method */
+    AIFF_open,      /*  open() method */
+    AIFF_close,     /* close() method */
+    AIFF_read       /*  read() method */
 };
 
 
@@ -135,6 +138,19 @@
 } comm_t;
 
 
+
+static int AIFF_init(void)
+{
+    return(1);  /* always succeeds. */
+} /* AIFF_init */
+
+
+static void AIFF_quit(void)
+{
+    /* it's a no-op. */
+} /* AIFF_quit */
+
+
 /*
  * Sample rate is encoded as an "80 bit IEEE Standard 754 floating point
  * number (Standard Apple Numeric Environment [SANE] data type Extended)".